@@ -73,6 +73,29 @@ class Bigoyster:
 
         response = requests.post(
             url, json=values, headers=self.get_headers(), timeout=5)
+        if response.status_code == 200:
+            result = json.loads(response.text)
+            return True, result
+        elif response.status_code == 401:
+            print('NOT AUTHORIZED')
+            if self.get_token(username=self.username, password=self.password):
+                print('RETRY')
+                return self.call_action_api(object, action, values)
+        elif response.status_code >= 400:
+            print('400s BAD REQUEST')
+            print(response.text)
+
+        else:
+            print('UNHANDLED STATUS CODE')
+            print(response.text)
+        return False, response
+
+    def call_update_api(self, object, objid, values):
+        baseurl = self.base_url
+        url = baseurl + object + '/update/' + objid + '/'
+
+        response = requests.put(
+            url, json=values, headers=self.get_headers(), timeout=5)
         print(response.elapsed)
         if response.status_code == 200:
             result = json.loads(response.text)
@@ -168,7 +191,7 @@ class Bigoyster:
 
     def get_consumer_coupons(
         self, device_id, consumer_id, upcs='', qtys='', prices='', txn_line_refs='', txn_ref='',
-        txn_type='sale', sale_auth='', sale_txn_ref='', sale_txn_ref_lines='', taxes=[]
+        txn_type='sale', sale_auth='', sale_txn_ref='', sale_txn_ref_lines='', taxes=[], labels=[]
     ):
         if txn_type == 'return' and not sale_auth:
             raise Exception('No auth code on refund')
@@ -204,7 +227,8 @@ class Bigoyster:
             'sale_auth': sale_auth,
             'sale_txn_ref': sale_txn_ref,
             'sale_txn_ref_lines': sale_txn_ref_lines,
-            'taxes': taxes
+            'taxes': taxes,
+            'labels': labels
         }
         # check if preprocessing required
         x = upcs.split(',')
